==> auto-ui-2.1.40.tgz: package/es/layout/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import IconBack from '../icon/back_s';
import IconClose from '../icon/close_s';
import IconError from '../icon/error';
import SafeArea from '../safe-area';
import Spin from '../spin/index';
import './style.scss';
var Layout = function (props) {
    var className = props.className, children = props.children, _a = props.useTopSafeArea, useTopSafeArea = _a === void 0 ? true : _a, _b = props.useBottomSafeArea, useBottomSafeArea = _b === void 0 ? true : _b, topSafeAreaColor = props.topSafeAreaColor, bottomSafeAreaColor = props.bottomSafeAreaColor, otherProps = __rest(props, ["className", "children", "useTopSafeArea", "useBottomSafeArea", "topSafeAreaColor", "bottomSafeAreaColor"]);
    var composeClassName = cn('x-app', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onTouchStart: function () { } }),
        useTopSafeArea && React.createElement(SafeArea, { inset: "top", color: topSafeAreaColor }),
        children,
        useBottomSafeArea && React.createElement(SafeArea, { inset: "bottom", color: bottomSafeAreaColor })));
};
var LayoutBody = /** @class */ (function (_super) {
    __extends(LayoutBody, _super);
    function LayoutBody(props) {
        var _this = _super.call(this, props) || this;
        _this.timer = 0;
        _this.scroll = function (e) {
            var onScroll = _this.props.onScroll;
            if (onScroll) {
                onScroll(e);
            }
            e.preventDefault();
            var onReachBottom = _this.props.onReachBottom;
            if (!onReachBottom || onReachBottom.disabled) {
                return;
            }
            var wrapper = e.target;
            var inner = wrapper.querySelector('.x-app-body__inner');
            if (inner && wrapper.className.indexOf('x-app-body') > -1) {
                _this.detectReachBottom(wrapper, inner);
            }
        };
        // 判断是否到达底部
        _this.detectReachBottom = function (wrapper, inner) {
            if (_this.state.bottomLoading) {
                return;
            }
            if (_this.timer) {
                clearTimeout(_this.timer);
            }
            _this.timer = setTimeout(function () {
                var h = inner.clientHeight;
                var bh = wrapper.clientHeight + wrapper.scrollTop;
                // 快滚动到底部时
                if (h - bh < 200) {
                    _this.handler();
                }
            }, 300);
        };
        _this.handler = function () {
            var onReachBottom = _this.props.onReachBottom;
            var callback = function () { return __awaiter(_this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(onReachBottom && onReachBottom.handler)) return [3 /*break*/, 2];
                            return [4 /*yield*/, onReachBottom.handler()];
                        case 1:
                            _a.sent();
                            _a.label = 2;
                        case 2:
                            this.setState({
                                bottomLoading: false,
                            });
                            return [2 /*return*/];
                    }
                });
            }); };
            _this.setState({ bottomLoading: true }, callback);
        };
        _this.state = {
            bottomLoading: false,
        };
        return _this;
    }
    LayoutBody.prototype.render = function () {
        var _a = this.props, loading = _a.loading, errorInfo = _a.errorInfo, className = _a.className, onScroll = _a.onScroll, onReachBottom = _a.onReachBottom, skeleton = _a.skeleton, _b = _a.skeletonRepeat, skeletonRepeat = _b === void 0 ? 1 : _b, otherProps = __rest(_a, ["loading", "errorInfo", "className", "onScroll", "onReachBottom", "skeleton", "skeletonRepeat"]);
        var composeClassName = cn('x-app-body', className, {
            'x-app-body--loading': loading,
            'x-app-body--error': errorInfo,
        });
        var skelotonClassName = cn('x-app-skeletonwrapper__skeleton', {
            skeletonHide: !loading,
        });
        if (skeleton) {
            return (React.createElement("div", { className: "x-app-skeletonwrapper" },
                React.createElement("div", { className: skelotonClassName }, '*'
                    .repeat(skeletonRepeat)
                    .split('')
                    .map(function (_, key) {
                    return React.createElement("div", { key: key }, skeleton);
                })),
                React.createElement("div", __assign({}, otherProps, { className: composeClassName, onScroll: onReachBottom ? this.scroll : onScroll }),
                    this.renderContent(),
                    this.renderReachBottom())));
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onScroll: onReachBottom ? this.scroll : onScroll }),
            this.renderContent(),
            this.renderReachBottom()));
    };
    LayoutBody.prototype.renderReachBottom = function () {
        var _a = this.props, onReachBottom = _a.onReachBottom, loading = _a.loading, errorInfo = _a.errorInfo;
        if (!onReachBottom || onReachBottom.disabled || loading || errorInfo) {
            return null;
        }
        return (React.createElement("div", { className: "x-app-body__bottom" },
            !this.state.bottomLoading && (React.createElement("button", { onClick: this.handler, className: "x-app-body__bottom-inner" }, onReachBottom.content || '加载更多')),
            !!this.state.bottomLoading && (React.createElement("div", { className: "x-app-body__bottom-inner" },
                React.createElement(Spin, null)))));
    };
    LayoutBody.prototype.renderContent = function () {
        var _a = this.props, loading = _a.loading, errorInfo = _a.errorInfo, children = _a.children, skeleton = _a.skeleton;
        if (loading && !skeleton) {
            return React.createElement(Spin, { className: "x-app__loading" });
        }
        if (errorInfo) {
            return (React.createElement("p", { className: "x-app__error-info" },
                React.createElement(IconError, null),
                errorInfo));
        }
        // const className = cn('x-app-body__skeleton', {
        //   skeletonHide: !loading,
        // })
        // return (
        //   <>
        //     {skeleton && (
        //       <div className={className}>
        //         {'*'
        //           .repeat(skeletonRepeat)
        //           .split('')
        //           .map((_, key) => {
        //             return <div key={key}>{skeleton}</div>
        //           })}
        //       </div>
        //     )}
        //     <div className="x-app-body__inner">{children}</div>
        //   </>
        // )
        return React.createElement("div", { className: "x-app-body__inner" }, children);
    };
    return LayoutBody;
}(React.PureComponent));
var LayoutFooter = function (props) {
    var className = props.className, visible = props.visible, children = props.children, otherProps = __rest(props, ["className", "visible", "children"]);
    var composeClassName = cn('x-app-footer', className);
    if (!visible) {
        return null;
    }
    return (React.createElement("footer", __assign({}, otherProps, { className: composeClassName }), children));
};
LayoutFooter.defaultProps = {
    visible: true,
};
var LayoutHeader = function (props) {
    var className = props.className, children = props.children, ghost = props.ghost, addonBefore = props.addonBefore, onBackClick = props.onBackClick, onCloseClick = props.onCloseClick, title = props.title, addonAfter = props.addonAfter, addonBottom = props.addonBottom, borderType = props.borderType, headline = props.headline, hideInAlipay = props.hideInAlipay, hideInAlipayMP = props.hideInAlipayMP, hideInApp = props.hideInApp, homepage = props.homepage, useSafeArea = props.useSafeArea, tabs = props.tabs, otherProps = __rest(props
    // headline模式下，如果标题上方没有内容，去掉上方的空隙
    , ["className", "children", "ghost", "addonBefore", "onBackClick", "onCloseClick", "title", "addonAfter", "addonBottom", "borderType", "headline", "hideInAlipay", "hideInAlipayMP", "hideInApp", "homepage", "useSafeArea", "tabs"]);
    // headline模式下，如果标题上方没有内容，去掉上方的空隙
    var fixPaddingTop = false;
    if (headline && !addonBefore && !onBackClick && !onCloseClick) {
        fixPaddingTop = true;
    }
    var composeClassName = cn('x-app-header', {
        'x-app-header--ghost': ghost,
        'x-app-header--has-tabs': !!tabs,
        'x-app-header--headline': headline,
        'x-app-header--headline-fix-padding': fixPaddingTop,
    }, className, borderType && borderType !== 'none' ? "x-app-header--bottom-" + borderType : void 0);
    // 在app中隐藏
    if (hideInApp && /atzuche/gi.test(navigator.userAgent)) {
        return null;
    }
    // 在支付宝中隐藏，包括扫一扫进入的网页和小程序
    if (hideInAlipay && /AlipayClient/gi.test(navigator.userAgent)) {
        return null;
    }
    // 在支付宝小程序中隐藏
    var isInAlipayMP = false;
    if (window.my && window.my.getEnv) {
        ;
        window.my.getEnv(function (res) {
            isInAlipayMP = !!res.miniprogram;
        });
    }
    if (hideInAlipayMP && isInAlipayMP) {
        return null;
    } // TODO: 异步获取是否在支付宝中的flag，所以这段代码有bug
    var gotoHomepage = function (evt) {
        if (!homepage)
            return;
        if (typeof homepage === 'string') {
            window.location.href = homepage;
        }
        else if (typeof homepage === 'boolean') {
            window.location.href = '/m/index';
        }
        else {
            homepage(evt);
        }
    };
    var _onBackClick = function (evt) {
        if (!onBackClick)
            return;
        if (typeof onBackClick === 'boolean') {
            window.history.back();
        }
        else {
            onBackClick(evt);
        }
    };
    var _onCloseClick = function (evt) {
        if (!onCloseClick)
            return;
        if (typeof onCloseClick === 'boolean') {
            window.history.back();
        }
        else {
            onCloseClick(evt);
        }
    };
    return (React.createElement("header", __assign({}, otherProps, { className: composeClassName }),
        useSafeArea && React.createElement(SafeArea, { inset: "top", color: "transparent" }),
        React.createElement("div", { className: "x-app-header__inner" },
            (addonBefore || onBackClick || onCloseClick) && (React.createElement("div", { className: "x-app-header__addon-before" },
                !!onBackClick && (React.createElement("button", { onClick: _onBackClick, className: "x-app-header__back" },
                    React.createElement(IconBack, null))),
                !!onCloseClick && (React.createElement("button", { onClick: _onCloseClick, className: "x-app-header__close" },
                    React.createElement(IconClose, null))),
                addonBefore)),
            !!title && React.createElement("h1", { className: "x-app-header__title" }, title),
            !title && children,
            (!!addonAfter || homepage) && (React.createElement("div", { className: "x-app-header__addon-after" },
                props.addonAfter,
                homepage && (React.createElement("button", { className: "x-app-header__homepage-button", onClick: gotoHomepage }))))),
        !!addonBottom && React.createElement("div", { className: "x-app-header__addon-bottom" }, props.addonBottom),
        !!tabs && tabs));
};
Layout.Header = LayoutHeader;
Layout.Body = LayoutBody;
Layout.Footer = LayoutFooter;
export default Layout;

==> auto-ui-2.1.41.tgz: package/es/layout/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import IconBack from '../icon/back_s';
import IconClose from '../icon/close_s';
import IconError from '../icon/error';
import SafeArea from '../safe-area';
import Spin from '../spin/index';
import './style.scss';
var Layout = function (props) {
    var className = props.className, children = props.children, _a = props.useTopSafeArea, useTopSafeArea = _a === void 0 ? true : _a, _b = props.useBottomSafeArea, useBottomSafeArea = _b === void 0 ? true : _b, topSafeAreaColor = props.topSafeAreaColor, bottomSafeAreaColor = props.bottomSafeAreaColor, otherProps = __rest(props, ["className", "children", "useTopSafeArea", "useBottomSafeArea", "topSafeAreaColor", "bottomSafeAreaColor"]);
    var composeClassName = cn('x-app', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onTouchStart: function () { } }),
        useTopSafeArea && React.createElement(SafeArea, { inset: "top", color: topSafeAreaColor }),
        children,
        useBottomSafeArea && React.createElement(SafeArea, { inset: "bottom", color: bottomSafeAreaColor })));
};
var LayoutBody = /** @class */ (function (_super) {
    __extends(LayoutBody, _super);
    function LayoutBody(props) {
        var _this = _super.call(this, props) || this;
        _this.timer = 0;
        _this.onAnimationEnd = function () {
            _this.setState({
                skeletonAnimationEnd: true,
            });
        };
        _this.scroll = function (e) {
            var onScroll = _this.props.onScroll;
            if (onScroll) {
                onScroll(e);
            }
            e.preventDefault();
            var onReachBottom = _this.props.onReachBottom;
            if (!onReachBottom || onReachBottom.disabled) {
                return;
            }
            var wrapper = e.target;
            var inner = wrapper.querySelector('.x-app-body__inner');
            if (inner && wrapper.className.indexOf('x-app-body') > -1) {
                _this.detectReachBottom(wrapper, inner);
            }
        };
        // 判断是否到达底部
        _this.detectReachBottom = function (wrapper, inner) {
            if (_this.state.bottomLoading) {
                return;
            }
            if (_this.timer) {
                clearTimeout(_this.timer);
            }
            _this.timer = setTimeout(function () {
                var h = inner.clientHeight;
                var bh = wrapper.clientHeight + wrapper.scrollTop;
                // 快滚动到底部时
                if (h - bh < 200) {
                    _this.handler();
                }
            }, 300);
        };
        _this.handler = function () {
            var onReachBottom = _this.props.onReachBottom;
            var callback = function () { return __awaiter(_this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!(onReachBottom && onReachBottom.handler)) return [3 /*break*/, 2];
                            return [4 /*yield*/, onReachBottom.handler()];
                        case 1:
                            _a.sent();
                            _a.label = 2;
                        case 2:
                            this.setState({
                                bottomLoading: false,
                            });
                            return [2 /*return*/];
                    }
                });
            }); };
            _this.setState({ bottomLoading: true }, callback);
        };
        _this.state = {
            bottomLoading: false,
            skeletonAnimationEnd: false,
        };
        return _this;
    }
    LayoutBody.prototype.render = function () {
        var _a = this.props, loading = _a.loading, errorInfo = _a.errorInfo, className = _a.className, onScroll = _a.onScroll, onReachBottom = _a.onReachBottom, skeleton = _a.skeleton, skeletonRepeat = _a.skeletonRepeat, otherProps = __rest(_a, ["loading", "errorInfo", "className", "onScroll", "onReachBottom", "skeleton", "skeletonRepeat"]);
        var composeClassName = cn('x-app-body', className, {
            'x-app-body--loading': loading,
            'x-app-body--error': errorInfo,
        });
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, onScroll: onReachBottom ? this.scroll : onScroll }),
            this.renderContent(),
            this.renderReachBottom()));
    };
    LayoutBody.prototype.renderReachBottom = function () {
        var _a = this.props, onReachBottom = _a.onReachBottom, loading = _a.loading, errorInfo = _a.errorInfo;
        if (!onReachBottom || onReachBottom.disabled || loading || errorInfo) {
            return null;
        }
        return (React.createElement("div", { className: "x-app-body__bottom" },
            !this.state.bottomLoading && (React.createElement("button", { onClick: this.handler, className: "x-app-body__bottom-inner" }, onReachBottom.content || '加载更多')),
            !!this.state.bottomLoading && (React.createElement("div", { className: "x-app-body__bottom-inner" },
                React.createElement(Spin, null)))));
    };
    LayoutBody.prototype.renderContent = function () {
        var _a = this.props, loading = _a.loading, errorInfo = _a.errorInfo, children = _a.children, skeleton = _a.skeleton, _b = _a.skeletonRepeat, skeletonRepeat = _b === void 0 ? 1 : _b;
        if (loading && !skeleton) {
            return React.createElement(Spin, { className: "x-app__loading" });
        }
        if (errorInfo) {
            return (React.createElement("p", { className: "x-app__error-info" },
                React.createElement(IconError, null),
                errorInfo));
        }
        var skelotonClassName = cn('x-app-skeletonwrapper', {
            skeletonAnimationStart: !loading,
        });
        if (skeleton && !this.state.skeletonAnimationEnd) {
            return (React.createElement(React.Fragment, null,
                React.createElement("div", { className: skelotonClassName, onAnimationEnd: this.onAnimationEnd }, '*'
                    .repeat(skeletonRepeat)
                    .split('')
                    .map(function (_, key) {
                    return React.createElement("div", { key: key }, skeleton);
                }))));
        }
        return React.createElement("div", { className: "x-app-body__inner" }, children);
    };
    return LayoutBody;
}(React.PureComponent));
var LayoutFooter = function (props) {
    var className = props.className, visible = props.visible, children = props.children, otherProps = __rest(props, ["className", "visible", "children"]);
    var composeClassName = cn('x-app-footer', className);
    if (!visible) {
        return null;
    }
    return (React.createElement("footer", __assign({}, otherProps, { className: composeClassName }), children));
};
LayoutFooter.defaultProps = {
    visible: true,
};
var LayoutHeader = function (props) {
    var className = props.className, children = props.children, ghost = props.ghost, addonBefore = props.addonBefore, onBackClick = props.onBackClick, onCloseClick = props.onCloseClick, title = props.title, addonAfter = props.addonAfter, addonBottom = props.addonBottom, borderType = props.borderType, headline = props.headline, hideInAlipay = props.hideInAlipay, hideInAlipayMP = props.hideInAlipayMP, hideInApp = props.hideInApp, homepage = props.homepage, useSafeArea = props.useSafeArea, tabs = props.tabs, otherProps = __rest(props
    // headline模式下，如果标题上方没有内容，去掉上方的空隙
    , ["className", "children", "ghost", "addonBefore", "onBackClick", "onCloseClick", "title", "addonAfter", "addonBottom", "borderType", "headline", "hideInAlipay", "hideInAlipayMP", "hideInApp", "homepage", "useSafeArea", "tabs"]);
    // headline模式下，如果标题上方没有内容，去掉上方的空隙
    var fixPaddingTop = false;
    if (headline && !addonBefore && !onBackClick && !onCloseClick) {
        fixPaddingTop = true;
    }
    var composeClassName = cn('x-app-header', {
        'x-app-header--ghost': ghost,
        'x-app-header--has-tabs': !!tabs,
        'x-app-header--headline': headline,
        'x-app-header--headline-fix-padding': fixPaddingTop,
    }, className, borderType && borderType !== 'none' ? "x-app-header--bottom-" + borderType : void 0);
    // 在app中隐藏
    if (hideInApp && /atzuche/gi.test(navigator.userAgent)) {
        return null;
    }
    // 在支付宝中隐藏，包括扫一扫进入的网页和小程序
    if (hideInAlipay && /AlipayClient/gi.test(navigator.userAgent)) {
        return null;
    }
    // 在支付宝小程序中隐藏
    var isInAlipayMP = false;
    if (window.my && window.my.getEnv) {
        ;
        window.my.getEnv(function (res) {
            isInAlipayMP = !!res.miniprogram;
        });
    }
    if (hideInAlipayMP && isInAlipayMP) {
        return null;
    } // TODO: 异步获取是否在支付宝中的flag，所以这段代码有bug
    var gotoHomepage = function (evt) {
        if (!homepage)
            return;
        if (typeof homepage === 'string') {
            window.location.href = homepage;
        }
        else if (typeof homepage === 'boolean') {
            window.location.href = '/m/index';
        }
        else {
            homepage(evt);
        }
    };
    var _onBackClick = function (evt) {
        if (!onBackClick)
            return;
        if (typeof onBackClick === 'boolean') {
            window.history.back();
        }
        else {
            onBackClick(evt);
        }
    };
    var _onCloseClick = function (evt) {
        if (!onCloseClick)
            return;
        if (typeof onCloseClick === 'boolean') {
            window.history.back();
        }
        else {
            onCloseClick(evt);
        }
    };
    return (React.createElement("header", __assign({}, otherProps, { className: composeClassName }),
        useSafeArea && React.createElement(SafeArea, { inset: "top", color: "transparent" }),
        React.createElement("div", { className: "x-app-header__inner" },
            (addonBefore || onBackClick || onCloseClick) && (React.createElement("div", { className: "x-app-header__addon-before" },
                !!onBackClick && (React.createElement("button", { onClick: _onBackClick, className: "x-app-header__back" },
                    React.createElement(IconBack, null))),
                !!onCloseClick && (React.createElement("button", { onClick: _onCloseClick, className: "x-app-header__close" },
                    React.createElement(IconClose, null))),
                addonBefore)),
            !!title && React.createElement("h1", { className: "x-app-header__title" }, title),
            !title && children,
            (!!addonAfter || homepage) && (React.createElement("div", { className: "x-app-header__addon-after" },
                props.addonAfter,
                homepage && (React.createElement("button", { className: "x-app-header__homepage-button", onClick: gotoHomepage }))))),
        !!addonBottom && React.createElement("div", { className: "x-app-header__addon-bottom" }, props.addonBottom),
        !!tabs && tabs));
};
Layout.Header = LayoutHeader;
Layout.Body = LayoutBody;
Layout.Footer = LayoutFooter;
export default Layout;
